.. Emperor documentation master file, created by
   sphinx-quickstart on Sat Sep 13 10:33:08 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Emperor's Documentation
=======================

Emperor is an interactive next generation tool for the analysis, visualization
and understanding of high throughput microbial ecology datasets.

The :ref:`genindex` lists the contents of this documentation.

.. toctree::
   :maxdepth: 4

   emperor_objects

Format Description:
===================

.. toctree::
   :maxdepth: 2

   formats


Citing Emperor
==============

Remember to cite Emperor if you use it in any published research, please
include the following citation:

.. note::
	**EMPeror: a tool for visualizing high-throughput microbial community data**. Vazquez-Baeza Y, Pirrung M, Gonzalez A, Knight R. Gigascience. 2013 Nov 26;2(1):16.


You can find the `Emperor paper here <http://www.gigasciencejournal.com/content/2/1/16/>`_, and the data presented in this paper can be found `here <http://gigadb.org/dataset/100068>`_.
